var languageNames = {
"en-US": "Inglés (EE. UU.)",
"sq": "Albanés",
"am": "Amárico",
"ar": "Árabe",
"ast": "Asturiano",
"bn": "Bengalí",
"bn-IN": "Bengalí (India)",
"bs": "Bosnio",
"bg": "Búlgaro",
"ca": "Catalán",
"ca-valencia": "Catalan (Valencia)",
"zh-CN": "Chino (simplificado)",
"zh-TW": "Chino (tradicional)",
"hr": "Croata",
"cs": "Checo",
"da": "Danés",
"nl": "Neerlandés",
"dz": "Butanés",
"en-GB": "Inglés (R. U.)",
"en-ZA": "Inglés (Sudáf.)",
"eo": "Esperanto",
"et": "Estonio",
"eu": "Vasco",
"fi": "Finés",
"fr": "Francés",
"gl": "Gallego",
"ka": "Georgiano",
"de": "Alemán",
"el": "Griego",
"gu": "Guyaratí",
"he": "Hebreo",
"hi": "Hindi",
"hu": "Húngaro",
"id": "Indonesio",
"is": "Islandés",
"it": "Italiano",
"ja": "Japonés",
"km": "Camboyano",
"ko": "Coreano",
"lo": "Lao",
"lv": "Letón",
"lt": "Lituano",
"mk": "Macedonio",
"ne": "Nepalí",
"nn": "Noruego nynorsk",
"nb": "Noruego bokmål",
"om": "Oromo",
"pl": "Polaco",
"pt": "Portugués",
"pt-BR": "Portuguese (Brazil)",
"ro": "Rumano",
"ru": "Ruso",
"sid": "Sidamo",
"si": "Cingalés",
"sk": "Eslovaco",
"sl": "Esloveno",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Español",
"sv": "Sueco",
"tg": "Tayiko",
"ta": "Tamil",
"bo": "Tibetano",
"tl": "Tagalo",
"tr": "Turco",
"ug": "Uigur",
"uk": "Ucraniano",
"vi": "Vietnamita",
};
